@@ -19,9 +19,9 @@ my $xml = XML::LibXML->load_xml(location => 'data/PhysicalConstants.xml');
 
 my $lib = 'lib';	# where is the lib directory
 mkdir "$lib/Astro/Constants" unless -d "$lib/Astro/Constants";
-open my $ac_fh, '>', "$lib/Astro/Constants.pm";
-open my $mks_fh, '>', "$lib/Astro/Constants/MKS.pm";
-open my $cgs_fh, '>', "$lib/Astro/Constants/CGS.pm";
+open my $ac_fh, '>:utf8', "$lib/Astro/Constants.pm";
+open my $mks_fh, '>:utf8', "$lib/Astro/Constants/MKS.pm";
+open my $cgs_fh, '>:utf8', "$lib/Astro/Constants/CGS.pm";
 
 write_module_header($ac_fh, 'Astro::Constants');
 write_module_header($mks_fh, 'Astro::Constants::MKS');
@@ -111,7 +111,7 @@ sub write_module_header {
 
 	print $fh <<HEADER;
 package $name;
-# ABSTRACT: This library provides physical constants for use in Physics and Astronomy based on values from CODATA2014.
+# ABSTRACT: This library provides physical constants for use in Physics and Astronomy based on values from 2018 CODATA.
 
 use 5.006;
 use strict;
@@ -239,6 +239,14 @@ sub write_pod_synopsis {
 This module provides physical and mathematical constants for use
 in Astronomy and Astrophysics.
 
+The values are stored in F<Physical_Constants.xml> in the B<data> directory
+and are mostly based on the 2018 CODATA values from NIST.
+
+B<NOTE:> Other popular languages are still using I<2014> CODATA values
+for their constants and may produce different results in comparison.
+On the roadmap is a set of modules to allow you to specify the year or
+data set for the values of constants, defaulting to the most recent.
+
 The C<:long> tag imports all the constants in their long name forms
 (i.e. GRAVITATIONAL).  Useful subsets can be imported with these tags:
 C<:fundamental> C<:conversion> C<:mathematics> C<:cosmology> 
@@ -250,9 +258,6 @@ Short forms of the constant names are included to provide backwards
 compatibility with older versions based on Jeremy Bailin's Astroconst
 library and are available through the import tag C<:short>.
 
-The values are stored in F<Physical_Constants.xml> in the B<data> directory
-and are mostly based on the 2014 CODATA values from NIST.
-
 Long name constants are constructed with the L<constant> pragma and
 are not interpolated in double quotish situations because they are 
 really inlined functions.
@@ -277,7 +282,8 @@ and which meeting of which standards body is responsible for its value?
 
 Trusting someone else's code does carry some risk, which you I<should> consider, 
 but have you also considered the risk of doing it yourself with no one else 
-to check your work?
+to check your work?  And, are you going to check for the latest values from NIST
+every 4 years?
 
 =head3 And plus, it's B<FASTER>
 
